EnableLocal

Function EnableLocal 

pub fn EnableLocal(
    board: c_int,
    addresses: &Vec<Addr4882>,
) -> Result<(), GpibError>
put devices into local mode.

EnableLocal() addresses all of the devices in the addressList array as listeners then sends the GTL (go to local) command byte, causing them to enter local mode. This requires that the board is the controller-in-charge. Note that while the REN (remote enable) bus line is asserted, the devices will return to remote mode the next time they are addressed.

If addressList is empty or NULL, then the REN line is unasserted and all devices enter local mode. The board must be system controller to change the state of the REN line.

See: Linux GPIB Reference