ReadStatusByte

Function ReadStatusByte 

pub fn ReadStatusByte(
    board: c_int,
    address: Addr4882,
) -> Result<c_short, GpibError>
serial poll a device

ReadStatusByte() causes the board specified by the board descriptor board_desc to serial poll the GPIB address specified by address. The status byte is stored at the location specified by the result pointer. If you wish to serial poll multiple devices, it may be slightly more efficient to use AllSPoll(). Serial polls may also be conducted with the ‘traditional API’ function ibrsp().

See: Linux GPIB Reference