ReceiveSetup

Function ReceiveSetup 

pub fn ReceiveSetup(board: c_int, address: Addr4882) -> Result<(), GpibError>
perform receive addressing

ReceiveSetup() addresses the device specified by address as talker, and addresses the interface board as listener. A subsequent RcvRespMsg() call will read data from the device.

You may find it simpler to use the slightly higher level function Receive(), since it does not require addressing and reading of data to be performed separately.

See: Linux GPIB Reference