Send

Function Send 

pub fn Send(
    board: c_int,
    address: Addr4882,
    buffer: &[u8],
    eot_mode: IbSendEOI,
) -> Result<(), GpibError>
perform send addressing and write data

Send() addresses the device specified by address as listener, then writes data onto the bus. It is equivalent to a SendList() except it only uses a single GPIB address to specify the listener instead of allowing an array of listeners.

See: Linux GPIB Reference